// This file is part of Invenio.
// Copyright (C) 2016 CERN.
//
// Invenio is free software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// Invenio is distributed in the hope that it will be
// useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Invenio; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
// MA 02111-1307, USA.
//
// In applying this license, CERN does not
// waive the privileges and immunities granted to it by virtue of its status
// as an Intergovernmental Organization or submit itself to any jurisdiction.

.main-header {
  background-color: #2c3e50;
  border-bottom: 3px solid #3b97d3;
}

.main-sidebar {
  background-color: #2c3e50;
  padding-top: 75px;
}

.navbar-brand > img {
  max-width: 100%;
  max-height: 50px;
  padding: 10px 0px 3px 0px;
}

.content-wrapper {
  background-color: white;
}

.sidebar-toggle {
  margin-top: 5px;
}

.treeview {
  &.active {
    background-color: #3b97d3;
    padding-bottom: 10px;

    a {
      color: #2c3e50;
    }
  }

  li.active {
    font-weight: bolder;
  }
}

.admin-form {
  padding-top: 15px;

  .form-control[type=checkbox] {
    -webkit-appearance: checkbox;
    appearance: checkbox;
    width: 13px;
    margin-top: 0;
    margin-bottom: 0;
    padding-top: 7px;
  }
}



.dropdown-menu {
  li > .navbar-content {
    height: 70px;

    .user-menu {
      padding: 10px;
      font-size: .9em;
    }
  }
}
